# Yoke with API Gateway

This example uses a Swagger template to create an API Gateway linked to the associated Lambda function.

1. Install requirements

        pip install -t lib -r src/requirements.txt
2. Deploy

        yoke deploy --stage dev
        Getting config from /home/ubuntu/yoketest ...
        Loading stage dev ...
        Getting AWS Account Credentials ...
        Verifying AWS Account Credentials ...
        Building Lambda package ...
        Uploading Lambda yokeHelloWorld to AWS Account 1234567890 for region us-east-1 ...
        Templating swagger.yml for region us-east-1 ...
        Uploading API to AWS Account 1234567890 for region us-east-1 ...
        Deploying API to dev stage ...
        API deployed! URL:
         https://<rest_api_id>.execute-api.us-east-1.amazonaws.com/dev
        Deployment complete!
3. Test API using the `<rest_api_id>` printed during deploy

        curl -v https://<rest_api_id>.execute-api.us-east-1.amazonaws.com/dev/hello
